@@ -3,7 +3,7 @@ use crate::Config;
 use std::{cell::RefCell, rc::Rc};
 use swc_ecmascript::{
     ast::*,
-    utils::{ident::IdentLike, ExprExt},
+    utils::ident::IdentLike,
     visit::{as_folder, noop_visit_mut_type, noop_visit_type, Fold, Visit, VisitMut, VisitWith},
 };
 
@@ -69,20 +69,20 @@ impl Visit for Analyzer<'_> {
                 ..
             })) = v.init.as_deref()
             {
-                if callee.is_ident_ref_to("require".into())
-                    && args.len() == 1
-                    && args[0].spread.is_none()
-                {
-                    if let Expr::Lit(Lit::Str(v)) = &*args[0].expr {
-                        let is_styled = if self.config.top_level_import_paths.is_empty() {
-                            &*v.value == "styled-components"
-                                || v.value.starts_with("styled-components/")
-                        } else {
-                            self.config.top_level_import_paths.contains(&v.value)
-                        };
+                if let Expr::Ident(callee) = &**callee {
+                    if &*callee.sym == "require" && args.len() == 1 && args[0].spread.is_none() {
+                        if let Expr::Lit(Lit::Str(v)) = &*args[0].expr {
+                            let is_styled = if self.config.top_level_import_paths.is_empty() {
+                                &*v.value == "styled-components"
+                                    || v.value.starts_with("styled-components/")
+                            } else {
+                                self.config.top_level_import_paths.contains(&v.value)
+                            };
 
-                        if is_styled {
-                            self.state.styled_required = Some(name.id.to_id());
+                            if is_styled {
+                                self.state.styled_required = Some(name.id.to_id());
+                                self.state.unresolved_ctxt = Some(callee.span.ctxt);
+                            }
                         }
                     }
                 }
